/** Copyright 2013 VMware, Inc. All rights reserved. -- VMware Confidential */

package com.vmware.samples.chassisRackVSphere;

import java.net.URI;

import com.vmware.samples.chassisRackVSphere.model.ChassisInfo;

/**
 * Interface to perform operations on the Chassis object.
 */
public interface ChassisService {
   /**
    * Creates a new chassis with the given chassisInfo values.
    *
    * @param chassisInfo
    *    Chassis data used to create new Chassis.
    *
    * @return
    *    Returns the URI reference of the newly created Chassis,
    *    or null if the creation failed because the name was already taken.
    */
   URI createChassis(ChassisInfo chassisInfo);

   /**
    * Edit the given chassis object.
    *
    * @param chassisRef Chassis reference.
    * @return true if the chassis was edited successfully.
    */
   boolean editChassis(URI chassisRef);

   /**
    * Delete the given chassis object.
    *
    * @param chassisRef  Chassis reference.
    * @return true if the chassis was deleted successfully.
    */
   boolean deleteChassis(URI chassisRef);

   /**
    * Add a host to a chassis if it wasn't present already. This also removes the host
    * from its previous chassis if any.
    *
    * @param hostRef
    *       Host object reference, i.e. must be handled by a VimObjectReferenceService
    * @param chassisRef
    *       Chassis reference, i.e. must be handled by an ObjectReferenceService
    * @return true if the host was added to the chassis.
    */
   boolean addHost(Object hostRef, URI chassisRef);

}
