/** Copyright 2012 VMware, Inc. All rights reserved. -- VMware Confidential */

package com.vmware.samples.test.chassisRack;

import java.util.concurrent.atomic.AtomicInteger;

import com.vmware.vise.data.ResourceSpec;
import com.vmware.vise.data.Constraint;
import com.vmware.vise.data.query.ObjectIdentityConstraint;
import com.vmware.vise.data.PropertySpec;
import com.vmware.vise.data.query.QuerySpec;
import com.vmware.vise.data.query.RelationalConstraint;
import com.vmware.vise.data.query.ResultSpec;

public class QueryUtil {

   private static final AtomicInteger COUNT = new AtomicInteger(0);

   public static Constraint getSimpleConstraint(String targetType) {
      Constraint cnstrnt = new Constraint();
      cnstrnt.targetType = targetType;
      return cnstrnt;
   }

   public static ObjectIdentityConstraint getObjectConstraint(Object objectRef) {
      ObjectIdentityConstraint objCnstrnt = new ObjectIdentityConstraint();
      objCnstrnt.target = objectRef;
      return objCnstrnt;
   }

   public static RelationalConstraint getRelationConstraint(
         Constraint cnstrntOnRelated,
         String relation,
         String targetType) {
      RelationalConstraint rlcnstrnt = new RelationalConstraint();
      rlcnstrnt.relation = relation;
      rlcnstrnt.constraintOnRelatedObject = cnstrntOnRelated;
      rlcnstrnt.targetType = targetType;
      return rlcnstrnt;
   }

   public static ResourceSpec getResourceSpec(
         Constraint cnstrnt,
         String[] properties) {
      ResourceSpec rsrcSpc = new ResourceSpec();
      rsrcSpc.constraint = cnstrnt;
      PropertySpec prptySpc = new PropertySpec();
      prptySpc.propertyNames = properties;
      rsrcSpc.propertySpecs = new PropertySpec[] {prptySpc};
      return rsrcSpc;
   }

   public static QuerySpec getQuerySpec(Object objectRef, String[] properties) {
      return getQuerySpec(
            getResourceSpec(getObjectConstraint(objectRef), properties));
   }

   public static QuerySpec getQuerySpec(String targetType, String[] properties) {
      return getQuerySpec(
            getResourceSpec(getSimpleConstraint(targetType), properties));
   }

   public static QuerySpec getQuerySpec(
         String targetType,
         String relation,
         Object relatedObjRef,
         String[] properties) {
      ObjectIdentityConstraint relatedObjCnstrnt =
            getObjectConstraint(relatedObjRef);
      RelationalConstraint rlCnstrnt = getRelationConstraint(
            relatedObjCnstrnt,
            relation,
            targetType);
      rlCnstrnt.hasInverseRelation = true;
      return getQuerySpec(getResourceSpec(rlCnstrnt, properties));
   }

   public static QuerySpec getQuerySpec(ResourceSpec rsrcSpc) {
      return getQuerySpec(rsrcSpc, getDefaultResultSpec());
   }

   public static QuerySpec getQuerySpec(
         ResourceSpec rsrcSpc,
         ResultSpec rsltSpc) {
      QuerySpec qrySpc = new QuerySpec();
      qrySpc.name = Integer.toString(COUNT.getAndIncrement());
      qrySpc.resultSpec = rsltSpc;
      qrySpc.resourceSpec = rsrcSpc;
      return qrySpc;
   }

   private static ResultSpec getDefaultResultSpec() {
      ResultSpec rsltSpc = new ResultSpec();
      rsltSpc.maxResultCount = -1; // No limitation on result count
      rsltSpc.offset = 0;          // Return results from the beginning
      rsltSpc.order = null;        // default ordering
      return rsltSpc;
   }

}
