/* Copyright 2012 VMware, Inc. All rights reserved. -- VMware Confidential */
package com.vmware.samples.globalview {
import com.vmware.flexutil.proxies.BaseProxy;

/**
* Proxy class for the EchoService java service
*/
public class EchoServiceProxy extends BaseProxy {
   // Service name matching the flex:remoting-destination declared in
   // main/webapp/WEB-INF/spring/bundle-context.xml
   private static const SERVICE_NAME:String = "EchoService";

   // channelUri uses the Web-ContextPath define in MANIFEST.MF (globalview-ui)
   // A secure AMF channel is required because vSphere Web Client uses https
   private static const CHANNEL_URI:String =
         "/" + GlobalviewModule.contextPath + "/messagebroker/amfsecure";

   /**
    * Create a EchoServiceProxy with a secure channel.
    */
   public function EchoServiceProxy() {
      super(SERVICE_NAME, CHANNEL_URI);
   }

   /**
    * Call the "echo" method of the EchoService java service.
    *
    * @param message    Single argument to the echo method
    * @param callback   Callback in the form <code>function(result:Object,
    *       error:Error, callContext:Object)</code>
    * @param context    Optional context object passed back with the result
    */
   public function echo(message:String, callback:Function = null, context:Object = null):void {
      // "echo" takes a single message argument but callService still requires an array.
      callService("echo", [message], callback, context);
   }
}
}